@@ -7,6 +7,7 @@ use warnings;
 use Class::Utils qw(set_params split_params);
 use Error::Pure qw(err);
 use List::Util 1.33 qw(none);
+use Mo::utils::CSS qw(check_css_unit);
 use Readonly;
 
 Readonly::Array our @HORIZ_ALIGN => qw(center left right);
@@ -19,14 +20,15 @@ Readonly::Hash our %VERT_CONV => (
 	'top' => 'flex-start',
 );
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 sub new {
 	my ($class, @params) = @_;
 
 	# Create object.
 	my ($object_params_ar, $other_params_ar) = split_params(
-		['css_container', 'css_inner', 'height', 'horiz_align', 'vert_align'], @params);
+		['css_container', 'css_inner', 'height', 'horiz_align',
+		'padding', 'vert_align'], @params);
 	my $self = $class->SUPER::new(@{$other_params_ar});
 
 	# Container align.
@@ -40,6 +42,9 @@ sub new {
 	# Height.
 	$self->{'height'} = '100vh';
 
+	# Padding.
+	$self->{'padding'} = undef;
+
 	# Process params.
 	set_params($self, @{$object_params_ar});
 
@@ -61,6 +66,9 @@ sub new {
 		;
 	}
 
+	check_css_unit($self, 'height');
+	check_css_unit($self, 'padding');
+
 	# Object.
 	return $self;
 }
@@ -126,6 +134,9 @@ sub _process_css {
 		['d', 'align-items', $VERT_CONV{$self->{'vert_align'}}],
 		['d', 'justify-content', $self->{'horiz_align'}],
 		['d', 'height', $self->{'height'}],
+		defined $self->{'padding'} ? (
+			['d', 'padding', $self->{'padding'}],
+		) : (),
 		['e'],
 	);
 	if (defined $css_cb) {
@@ -200,6 +211,12 @@ Possible values are: center left right
 
 Default value is 'center'.
 
+=item * C<padding>
+
+Container padding.
+
+Default value is undef.
+
 =item * C<vert_align>
 
 Vertical align.
@@ -268,6 +285,21 @@ Returns undef.
  new():
          From Class::Utils::set_params():
                  Unknown parameter '%s'.
+         from Mo::utils::CSS::check_css_unit():
+                 Parameter 'height' doesn't contain number.
+                         Value: %s
+                 Parameter 'height' doesn't contain unit.
+                         Value: %s
+                 Parameter 'height' contain bad unit.
+                         Unit: %s
+                         Value: %s
+                 Parameter 'padding' doesn't contain number.
+                         Value: %s
+                 Parameter 'padding' doesn't contain unit.
+                         Value: %s
+                 Parameter 'padding' contain bad unit.
+                         Unit: %s
+                         Value: %s
          From Tags::HTML::new():
                  Parameter 'css' must be a 'CSS::Struct::Output::*' class.
                  Parameter 'tags' must be a 'Tags::Output::*' class.
@@ -287,7 +319,7 @@ Returns undef.
          From Tags::HTML::process_css():
                  Parameter 'css' isn't defined.
 
-=head1 EXAMPLE
+=head1 EXAMPLE1
 
 =for comment filename=container_with_text.pl
 
@@ -335,11 +367,57 @@ Returns undef.
  #         height: 100vh;
  # }
 
+=head1 EXAMPLE2
+
+=for comment filename=plack_app_change_password.pl
+
+ use strict;
+ use warnings;
+ 
+ use CSS::Struct::Output::Indent;
+ use Plack::App::Tags::HTML;
+ use Plack::Runner;
+ use Tags::HTML::ChangePassword;
+ use Tags::Output::Indent;
+ 
+ my $css = CSS::Struct::Output::Indent->new;
+ my $tags = Tags::Output::Indent->new(
+         'xml' => 1,
+         'preserved' => ['style'],
+ );
+ my $change_password = Tags::HTML::ChangePassword->new(
+         'css' => $css,
+         'tags' => $tags,
+ );
+ $change_password->process_css;
+ my $app = Plack::App::Tags::HTML->new(
+         'component' => 'Tags::HTML::Container',
+         'data' => [sub {
+                 my $self = shift;
+                 $change_password->process;
+                 return;
+         }],
+         'css' => $css,
+         'tags' => $tags,
+ )->to_app;
+ Plack::Runner->new->run($app);
+
+ # Output screenshot is in images/ directory.
+
+=begin html
+
+<a href="https://raw.githubusercontent.com/michal-josef-spacek/Tags-HTML-Container/master/images/plack_app_change_password.png">
+  <img src="https://raw.githubusercontent.com/michal-josef-spacek/Tags-HTML-Container/master/images/plack_app_change_password.png" alt="Web app example" width="300px" height="300px" />
+</a>
+
+=end html
+
 =head1 DEPENDENCIES
 
 L<Class::Utils>,
 L<Error::Pure>,
 L<List::Util>,
+L<Mo::utils::CSS>,
 L<Readonly>,
 L<Tags::HTML>,
 
@@ -361,6 +439,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
